# Welcome to geoml_kit


[![image](https://img.shields.io/pypi/v/geoml_kit.svg)](https://pypi.python.org/pypi/geoml_kit)


**Python Boilerplate contains all the boilerplate you need to create a Python package.**


-   Free software: MIT License
-   Documentation: <https://Fariborz-Nasr.github.io/geoml_kit>


## Features

-   Create interactive maps
-   Process geospatial data

## Usage

```python
import geoml_kit
```

